Subsystem

Trait Subsystem 

pub trait Subsystem:
    Send
    + Sync
    + 'static { }
Subsystem of the kernel.

There should be only one instance for each subsystem. Normally it will live forever until the machine is shutdown. That means it is okay to to leak it.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors